<?php
namespace NeosRulez\Shop\Mollie\Controller;

/*
 * This file is part of the NeosRulez.Shop.Mollie package.
 */

use Neos\Flow\Annotations as Flow;
use Neos\Flow\Mvc\Controller\ActionController;
use Neos\Flow\Mvc\View\JsonView;

class MollieController extends ActionController
{

    /**
     * @var string string
     */
    protected $defaultViewObjectName = JsonView::class;

    /**
     * @Flow\Inject
     * @var \NeosRulez\Shop\Domain\Repository\OrderRepository
     */
    protected $orderRepository;

    /**
     * @Flow\Inject
     * @var \NeosRulez\Shop\Service\FinisherService
     */
    protected $finisherService;

    /**
     * @Flow\InjectConfiguration(package="NeosRulez.Shop", path="Payment.mollie")
     * @var array
     */
    protected $mollie;

    /**
     * @param string $orderId
     * @return void
     */
    public function verifyAction(string $orderId):void
    {
        if($this->request->hasArgument('id')) {
            $paymentId = $this->request->getArgument('id');

            $mollie = new \Mollie\Api\MollieApiClient();
            $mollie->setApiKey($this->mollie['args']['apiKey']);
            $payment = $mollie->payments->get($paymentId);

            if($payment->isPaid()) {
                $order = $this->orderRepository->findByOrderNumber($orderId);
                $order->setPaid(1);
                $order->setCanceled(0);
                $this->orderRepository->update($order);
                $this->persistenceManager->persistAll();

                $this->finisherService->initAfterPaymentFinishers($order->getInvoicedata());

                $this->view->assign('value', ['response' => true]);
            }
            $this->view->assign('value', ['response' => false]);
        }
    }

}
