<?php
namespace NeosRulez\Shop\Mollie\Domain\Service\Payment;

use Neos\Flow\Annotations as Flow;
use Doctrine\ORM\Mapping as ORM;

/**
 * Class Mollie
 *
 * @Flow\Scope("singleton")
 */
class Mollie
{

    /**
     * @Flow\InjectConfiguration(package="NeosRulez.Shop")
     * @var array
     */
    protected $settings = [];

    /**
     * @param array $payment
     * @param array $args
     * @param string $success_uri
     * @param string $failure_uri
     * @return string
     */
    public function execute($payment, $args, $success_uri, $failure_uri):string
    {
        $amount = number_format($args['summary']['total'], 2, '.', '');

        $mollie = new \Mollie\Api\MollieApiClient();
        $mollie->setApiKey($this->settings['Payment']['mollie']['args']['apiKey']);

        $uri = parse_url($success_uri);
        $mollieRedirectUri = $uri['scheme'] . '://' . $uri['host'];

        $payment = $mollie->payments->create([
            "amount" => [
                "currency" => "EUR",
                "value" => $amount
            ],
            "description" => 'Order: ' . $args['order_number'],
            "redirectUrl" => str_replace('&paid=1', '', $success_uri),
            "webhookUrl" => $mollieRedirectUri . '/mollie-webhook/' . $args['order_number']
        ]);

        return $payment->getCheckoutUrl();
    }

}
